@@ -15,12 +15,7 @@ spark_line <- function(x) {
   ind[, 2] <- ind[, 2] + 4
 
   chars <- apply(ind, 1, braille)
-  structure(paste0(chars, collapse = ""), class = "spark")
-}
-
-#' @export
-print.spark <- function(x, ...) {
-  cat(x, "\n", sep = "")
+  new_vertical(paste0(chars, collapse = ""), class = c("pillar_spark_line", "pillar_spark"))
 }
 
 # https://en.wikipedia.org/wiki/Braille_Patterns
@@ -29,10 +24,10 @@ braille <- function(x) {
   x <- c(7L, 3L, 2L, 1L, 8L, 6L, 5L, 4L)[x]
 
   raised <- 1:8 %in% x
-  binary <- raised * 2 ^ (0:7)
+  binary <- raised * 2^(0:7)
 
   # offset in hex is 2800
-  val <- 10240 + sum(raised * 2 ^ (0:7))
+  val <- 10240 + sum(raised * 2^(0:7))
 
   intToUtf8(val)
 }
